import request from '@/utils/request'
// 案件列表
export function caseApplicationList(data) {
    return request({
        url: '/caseApplication/list',
        // headers: {
        //   isToken: false
        // },
        method: 'get',
        params: data
    })
}
// 查看详情
export function caseApplicationDetail(data) {
    return request({
        url: '/caseApplication/selectCaseApplication',
        // headers: {
        //   isToken: false
        // },
        method: 'post',
        data: data
    })
}
// 检验裁决书
export function verificationArbitrateRecord(data) {
    return request({
        url: '/caseApplication/verificationArbitrateRecord',
        // headers: {
        //   isToken: false
        // },
        method: 'post',
        data: data
    })
}
// 审核裁决书
export function checkArbitrateRecord(data) {
    return request({
        url: '/caseApplication/checkArbitrateRecord',
        // headers: {
        //   isToken: false
        // },
        method: 'post',
        data: data
    })
}
// 裁决书送达 
export function adjudicationDelivery(data) {
    return request({
        url: '/adjudication/delivery',
        method: 'post',
        data: data
    })
}
// 送达(不包含发送电子邮件)
export function adjudicationService(data) {
    return request({
        url: '/adjudication/service',
        method: 'post',
        data: data
    })
}
// 查询物流信息
export function adjudicationLogistics(data) {
    return request({
        url: '/adjudication/logistics',
        method: 'get',
        params: data
    })
}
// // 签名(暂时只改案件状态)
// export function adjudicationSignature(data) {
//     return request({
//         url: '/adjudication/signature',
//         method: 'post',
//         data: data
//     })
// }
export function selectSignUrl(data) {
    return request({
        url: '/caseApplication/selectSignUrl',
        method: 'post',
        data: data
    })
}
// 归档(暂时只改案件状态)
export function adjudicationCaseFile(data) {
    return request({
        url: '/adjudication/caseFile',
        method: 'post',
        data: data
    })
}
// 用印(暂时只改案件状态)
// export function adjudicationStamp(data) {
//     return request({
//         url: '/adjudication/stamp',
//         method: 'post',
//         data: data
//     })
// }

export function selectSealUrl(data) {
    return request({
        url: '/caseApplication/selectSealUrl',
        method: 'post',
        data: data
    })
}
// 裁决书列表查询裁决书
export function selectSignSealUrl(data) {
    return request({
        url: '/caseApplication/selectSignSealUrl',
        method: 'post',
        data: data
    })
}

// 重新生成裁决书
export function regenerationDocument(data) {
    return request({
        url: '/adjudication/regenerationDocument',
        method: 'post',
        data: data
    })
}
// 根据案件id
export function emailByCaseId(data) {
    return request({
        url: '/adjudication/emailByCaseId',
        method: 'get',
        params: data
    })
}
